==> stooop-3.3.tar.gz: stooop-3.3/86.tcl <==
foreach name [array names env STOOOP*] {unset env($name)}                                ;# reset any existing environment variables
set env(STOOOPCHECKDATA) {}
source stooop.tcl
namespace import stooop::*

### verify member writing and unsetting within class procedures in member data checking mode
### it seems that unset tracing prevents error reporting at this time (bug?) ###

## can't set "b::(1,m)": class access violation in procedure ::a::p
## can't set "b::(n)": class access violation in procedure ::a::q
## bug
## bug
## can't set "B::(2,m)": class access violation in procedure ::A::p
## can't set "B::(n)": class access violation in procedure ::A::q
## bug
## bug
## can't set "c::e::(3,m)": class access violation in procedure ::c::d::p
## can't set "c::e::(n)": class access violation in procedure ::c::d::q
## bug
## bug
## can't set "C::E::(4,m)": class access violation in procedure ::C::D::p
## can't set "C::E::(n)": class access violation in procedure ::C::D::q
## bug
## bug
## can't set "C::E::(4,m)": class access violation in procedure ::C::D::p
## can't set "C::E::(n)": class access violation in procedure ::C::D::q
## bug
## bug

class a {}
proc a::a {this} {}
proc a::~a {this} {}
proc a::p {this} {
    set b::($this,m) 0
}
proc a::q {this} {
    set b::(n) 0
}
proc a::r {this} {
    unset b::($this,m)
}
proc a::s {this} {
    unset b::(n)
}
set o [new a]
class b {}
set b::($o,m) 0
set b::(n) 0
catch {a::p $o} message; puts $message
catch {a::q $o} message; puts $message
catch {a::r $o} message; puts bug
catch {a::s $o} message; puts bug
delete $o

class A {
    proc A {this} {}
    proc ~A {this} {}
    proc p {this} {
        set B::($this,m) 0
    }
    proc q {this} {
        set B::(n) 0
    }
    proc r {this} {
        unset B::($this,m)
    }
    proc s {this} {
        unset B::(n)
    }
}
set o [new A]
class B {
    set B::($o,m) 0
    set B::(n) 0
}
class A {
    catch {p $o} message; puts $message
    catch {q $o} message; puts $message
    catch {r $o} message; puts bug
    catch {s $o} message; puts bug
}
delete $o

class c {}
class c::d {}
proc c::d::d {this} {}
proc c::d::~d {this} {}
proc c::d::p {this} {
    set c::e::($this,m) 0
}
proc c::d::q {this} {
    set c::e::(n) 0
}
proc c::d::r {this} {
    unset c::e::($this,m)
}
proc c::d::s {this} {
    unset c::e::(n)
}
class c::e {}
set o [new c::d]
set c::e::($o,m) 0
set c::e::(n) 0
catch {c::d::p $o} message; puts $message
catch {c::d::q $o} message; puts $message
catch {c::d::r $o} message; puts bug
catch {c::d::s $o} message; puts bug
delete $o

class C {
    class D {
        proc D {this} {}
        proc ~D {this} {}
        proc p {this} {
            set C::E::($this,m) 0
        }
        proc q {this} {
            set C::E::(n) 0
        }
        proc r {this} {
            unset C::E::($this,m)
        }
        proc s {this} {
            unset C::E::(n)
        }
    }
    set ::o [new D]
    class E {
        set C::E::($o,m) 0
        set C::E::(n) 0
    }
    class D {
        catch {p $o} message; puts $message
        catch {q $o} message; puts $message
        catch {r $o} message; puts bug
        catch {s $o} message; puts bug
    }
}
catch {C::D::p $o} message; puts $message
catch {C::D::q $o} message; puts $message
catch {C::D::r $o} message; puts bug
catch {C::D::s $o} message; puts bug
delete $o

==> stooop-4.1.1.tar.gz: stooop-4.1.1/86.tcl <==
foreach name [array names env STOOOP*] {unset env($name)}                                ;# reset any existing environment variables
set env(STOOOPCHECKDATA) 1
source stooop.tcl
namespace import stooop::*

### verify member writing and unsetting within class procedures in member data checking mode
### it seems that unset tracing prevents error reporting at this time (bug?) ###

## can't set "b::(1,m)": class access violation in procedure ::a::p
## can't set "b::(n)": class access violation in procedure ::a::q
## bug
## bug
## can't set "B::(2,m)": class access violation in procedure ::A::p
## can't set "B::(n)": class access violation in procedure ::A::q
## bug
## bug
## can't set "c::e::(3,m)": class access violation in procedure ::c::d::p
## can't set "c::e::(n)": class access violation in procedure ::c::d::q
## bug
## bug
## can't set "C::E::(4,m)": class access violation in procedure ::C::D::p
## can't set "C::E::(n)": class access violation in procedure ::C::D::q
## bug
## bug
## can't set "C::E::(4,m)": class access violation in procedure ::C::D::p
## can't set "C::E::(n)": class access violation in procedure ::C::D::q
## bug
## bug

class a {}
proc a::a {this} {}
proc a::~a {this} {}
proc a::p {this} {
    set b::($this,m) 0
}
proc a::q {this} {
    set b::(n) 0
}
proc a::r {this} {
    unset b::($this,m)
}
proc a::s {this} {
    unset b::(n)
}
set o [new a]
class b {}
set b::($o,m) 0
set b::(n) 0
catch {a::p $o} message; puts $message
catch {a::q $o} message; puts $message
catch {a::r $o} message; puts bug
catch {a::s $o} message; puts bug
delete $o

class A {
    proc A {this} {}
    proc ~A {this} {}
    proc p {this} {
        set B::($this,m) 0
    }
    proc q {this} {
        set B::(n) 0
    }
    proc r {this} {
        unset B::($this,m)
    }
    proc s {this} {
        unset B::(n)
    }
}
set o [new A]
class B {
    set ($o,m) 0
    set (n) 0
}
class A {
    catch {p $o} message; puts $message
    catch {q $o} message; puts $message
    catch {r $o} message; puts bug
    catch {s $o} message; puts bug
}
delete $o

class c {}
class c::d {}
proc c::d::d {this} {}
proc c::d::~d {this} {}
proc c::d::p {this} {
    set c::e::($this,m) 0
}
proc c::d::q {this} {
    set c::e::(n) 0
}
proc c::d::r {this} {
    unset c::e::($this,m)
}
proc c::d::s {this} {
    unset c::e::(n)
}
class c::e {}
set o [new c::d]
set c::e::($o,m) 0
set c::e::(n) 0
catch {c::d::p $o} message; puts $message
catch {c::d::q $o} message; puts $message
catch {c::d::r $o} message; puts bug
catch {c::d::s $o} message; puts bug
delete $o

class C {
    class D {
        proc D {this} {}
        proc ~D {this} {}
        proc p {this} {
            set C::E::($this,m) 0
        }
        proc q {this} {
            set C::E::(n) 0
        }
        proc r {this} {
            unset C::E::($this,m)
        }
        proc s {this} {
            unset C::E::(n)
        }
    }
    set ::o [new D]
    class E {
        set ($o,m) 0
        set (n) 0
    }
    class D {
        catch {p $o} message; puts $message
        catch {q $o} message; puts $message
        catch {r $o} message; puts bug
        catch {s $o} message; puts bug
    }
}
catch {C::D::p $o} message; puts $message
catch {C::D::q $o} message; puts $message
catch {C::D::r $o} message; puts bug
catch {C::D::s $o} message; puts bug
delete $o
